<?php

function getAllContacts($privateAppToken,$hourl_rate,$service_area,$contact_type) {
    $contacts = [];
    $hasMore = true;
    $after = null;
    
    while ($hasMore) {
        // Build request payload
        $data = [
            'limit' => 100,
            'filterGroups' => [
                [
                    'filters' => [
                        [
                           "operator" => "EQ",
                            "propertyName" => "cp_hourly_rate",
                            "value"=> $hourl_rate
                        ],
                        [
                            'propertyName' => 'cp___service_area',
                            'operator' => 'EQ',
                            'value' => $service_area
                        ],
                         [
                            'propertyName' => 'contact_type',
                            'operator' => 'EQ',
                            'value' => $contact_type
                        ],
                        [
                            'propertyName' => 'cp___status',
                            'operator' => 'EQ',
                            'value' => 'Whitelist'
                        ]
                    ]
                ]
            ],
            'properties' => ['firstname', 'lastname', 'phone']
        ];

        // Add 'after' cursor if it's not the first request
        if ($after) {
            $data['after'] = $after;
        }

        // Initialize cURL session
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, "https://api.hubapi.com/crm/v3/objects/contacts/search");
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            'Content-Type: application/json',
            'Authorization: Bearer ' . $privateAppToken  // Using Private App Token for Authorization
        ]);

        // Execute the request
        $response = curl_exec($ch);

        // Handle cURL error
        if (curl_errno($ch)) {
            echo 'Error:' . curl_error($ch);
            break;
        }

        // Close cURL session
        curl_close($ch);

        // Parse the JSON response
        $responseData = json_decode($response, true);
        // Add the current batch of contacts to the results array
        if (isset($responseData['results'])) {
            $contacts = array_merge($contacts, $responseData['results']);
        }

        // Check if more pages of results exist
        if (isset($responseData['paging']['next']['after'])) {
            $after = $responseData['paging']['next']['after'];
        } else {
            $hasMore = false;  // No more results
        }
    }

    return $contacts;
}

function getuserSucessTeam($privateAppToken) {
    $contacts = [];
    $hasMore = true;
    $after = null;
    
    while ($hasMore) {
        // Build request payload
        $data = [
            'limit' => 100,
            'filterGroups' => [
                [
                    'filters' => [
                        [
                           "operator" => "EQ",
                            "propertyName" => "contact_type",
                            "value"=> "Production and User Success"
                        ]
                    ]
                ]
            ]
        ];

        // Add 'after' cursor if it's not the first request
        if ($after) {
            $data['after'] = $after;
        }

        // Initialize cURL session
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, "https://api.hubapi.com/crm/v3/objects/contacts/search");
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            'Content-Type: application/json',
            'Authorization: Bearer ' . $privateAppToken  // Using Private App Token for Authorization
        ]);

        // Execute the request
        $response = curl_exec($ch);

        // Handle cURL error
        if (curl_errno($ch)) {
            echo 'Error:' . curl_error($ch);
            break;
        }

        // Close cURL session
        curl_close($ch);

        // Parse the JSON response
        $responseData = json_decode($response, true);
        // Add the current batch of contacts to the results array
        if (isset($responseData['results'])) {
            $contacts = array_merge($contacts, $responseData['results']);
        }

        // Check if more pages of results exist
        if (isset($responseData['paging']['next']['after'])) {
            $after = $responseData['paging']['next']['after'];
        } else {
            $hasMore = false;  // No more results
        }
    }

    return $contacts;
}

function updateContactsInBatch($privateAppToken, $contacts,$notification,$job_id,$event_catergory,$event_location,$event_hourly_rate,$event_date_time) {
    // Prepare the batch update data (this will update the 'firstname' property for demo purposes)
    
    $updateData = ['inputs' => []];

    foreach ($contacts as $contact) {
        
        $updateData['inputs'][] = [
            'id' => $contact['id'],
            'properties' => [
                'job_email_triggers' => $notification,  // Example property change
                "job_id" => $job_id,
                "job_type" => $event_catergory,
                "swapper__event_location" =>$event_location,
                "swapper__event_hourly_rate" => $event_hourly_rate,
                "job_date___time" => $event_date_time,
            ]
        ];
    }
    
    print_r($updateData);
    
    // Initialize cURL session for batch update
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, "https://api.hubapi.com/crm/v3/objects/contacts/batch/update");
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($updateData));
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        'Content-Type: application/json',
        'Authorization: Bearer ' . $privateAppToken
    ]);

    // Execute the batch update request
    $response = curl_exec($ch);

    // Handle cURL error
    if (curl_errno($ch)) {
        echo 'Error:' . curl_error($ch);
        return;
    }

    // Close cURL session
    curl_close($ch);

    // Parse the response
    $responseData = json_decode($response, true);
    
    // Check for errors or success
    if (isset($responseData['status']) && $responseData['status'] === 'error') {
        return 'Batch Update Failed: ' . $responseData['message'] . "\n";
    } else {
        return "Batch Update Success: " . count($updateData['inputs']) . " contacts updated.\n";
    }
}

function CPisNotAvailable($dealId,$accessToken) {
    
    $url = "https://api.hubapi.com/crm/v3/objects/deals/{$dealId}";

    // Prepare data for the property update
    $data = [
        'properties' => [
            'cp_not_available' => true
        ]
    ];

    // Convert the data array to JSON
    $jsonData = json_encode($data);

    // Initialize cURL session
    $ch = curl_init($url);

    // Set cURL options
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "PATCH");
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        "Content-Type: application/json",
        "Authorization: Bearer " . $accessToken
    ]);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $jsonData);

    // Execute the cURL request and capture the response
    $response = curl_exec($ch);

    // Check for errors in the request
    if (curl_errno($ch)) {
        echo 'Error:' . curl_error($ch);
    } else {
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        if ($httpCode === 200) {
            echo "Deal property updated successfully.";
        } else {
            echo "Failed to update deal property. Response: " . $response;
        }
    }

    // Close the cURL session
    curl_close($ch);
}

function DealPipelineStage($privateAppToken, $dealId)
{
          $curl = curl_init();
          curl_setopt_array($curl, array(
          CURLOPT_URL => 'https://api.hubapi.com/crm/v3/objects/deals/'.$dealId.'?properties=job_status_for_cp_s',
          CURLOPT_RETURNTRANSFER => true,
          CURLOPT_ENCODING => '',
          CURLOPT_MAXREDIRS => 10,
          CURLOPT_TIMEOUT => 0,
          CURLOPT_FOLLOWLOCATION => true,
          CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
          CURLOPT_CUSTOMREQUEST => 'GET',
          CURLOPT_HTTPHEADER => array(
            'Content-Type: application/json',
            'Authorization: ' . 'Bearer ' . $privateAppToken,
          ),
        ));
        
        $deal_response = curl_exec($curl);
        curl_close($curl);
        
        $responseData = json_decode( $deal_response , true);
        return $responseData;
    
}

function UpdateJobStatus($privateAppToken, $jobId,$jobstatus)
{
              
              $update_deal_curl = curl_init();
              curl_setopt_array($update_deal_curl, array(
              CURLOPT_URL => 'https://api.hubapi.com/crm/v3/objects/deals/' . $jobId,
              CURLOPT_RETURNTRANSFER => true,
              CURLOPT_ENCODING => '',
              CURLOPT_MAXREDIRS => 10,
              CURLOPT_TIMEOUT => 0,
              CURLOPT_FOLLOWLOCATION => true,
              CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
              CURLOPT_CUSTOMREQUEST => 'PATCH',
              CURLOPT_POSTFIELDS =>'{
                "properties": {
                      "job_status_for_cp_s" :"'.$jobstatus.'"'.
                '}
              }',
              CURLOPT_HTTPHEADER => array(
                'Content-Type: application/json',
                'Authorization: Bearer ' . $privateAppToken,
              ),
            ));
        
            $deal_update_response = curl_exec($update_deal_curl);
            curl_close($update_deal_curl);
            return $deal_update_response;

}

function DealTotalJob($privateAppToken, $dealId)
{
          $curl = curl_init();
          curl_setopt_array($curl, array(
          CURLOPT_URL => 'https://api.hubapi.com/crm/v3/objects/deals/'.$dealId.'?properties=total_jobs',
          CURLOPT_RETURNTRANSFER => true,
          CURLOPT_ENCODING => '',
          CURLOPT_MAXREDIRS => 10,
          CURLOPT_TIMEOUT => 0,
          CURLOPT_FOLLOWLOCATION => true,
          CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
          CURLOPT_CUSTOMREQUEST => 'GET',
          CURLOPT_HTTPHEADER => array(
            'Content-Type: application/json',
            'Authorization: ' . 'Bearer ' . $privateAppToken,
          ),
        ));
        
        $deal_response = curl_exec($curl);
        curl_close($curl);
        
        $responseData = json_decode( $deal_response , true);
        return $responseData;
    
}

function UpdateTotalJob($privateAppToken, $jobId,$totalJob)
{
              
              $update_deal_curl = curl_init();
              curl_setopt_array($update_deal_curl, array(
              CURLOPT_URL => 'https://api.hubapi.com/crm/v3/objects/deals/' . $jobId,
              CURLOPT_RETURNTRANSFER => true,
              CURLOPT_ENCODING => '',
              CURLOPT_MAXREDIRS => 10,
              CURLOPT_TIMEOUT => 0,
              CURLOPT_FOLLOWLOCATION => true,
              CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
              CURLOPT_CUSTOMREQUEST => 'PATCH',
              CURLOPT_POSTFIELDS =>'{
                "properties": {
                      "total_jobs" :"'.$totalJob.'"'.
                '}
              }',
              CURLOPT_HTTPHEADER => array(
                'Content-Type: application/json',
                'Authorization: Bearer ' . $privateAppToken,
              ),
            ));
        
            $deal_update_response = curl_exec($update_deal_curl);
            curl_close($update_deal_curl);
            return $deal_update_response;

}

function DealTotalVideographer($privateAppToken, $dealId)
{
          $curl = curl_init();
          curl_setopt_array($curl, array(
          CURLOPT_URL => 'https://api.hubapi.com/crm/v3/objects/deals/'.$dealId.'?properties=number_of_videographer',
          CURLOPT_RETURNTRANSFER => true,
          CURLOPT_ENCODING => '',
          CURLOPT_MAXREDIRS => 10,
          CURLOPT_TIMEOUT => 0,
          CURLOPT_FOLLOWLOCATION => true,
          CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
          CURLOPT_CUSTOMREQUEST => 'GET',
          CURLOPT_HTTPHEADER => array(
            'Content-Type: application/json',
            'Authorization: ' . 'Bearer ' . $privateAppToken,
          ),
        ));
        
        $deal_response = curl_exec($curl);
        curl_close($curl);
        
        $responseData = json_decode( $deal_response , true);
        return $responseData;
    
}


function UpdateNumOfVideographer($privateAppToken, $jobId, $num_of_videographer)
{
              
              $update_deal_curl = curl_init();
              curl_setopt_array($update_deal_curl, array(
              CURLOPT_URL => 'https://api.hubapi.com/crm/v3/objects/deals/' . $jobId,
              CURLOPT_RETURNTRANSFER => true,
              CURLOPT_ENCODING => '',
              CURLOPT_MAXREDIRS => 10,
              CURLOPT_TIMEOUT => 0,
              CURLOPT_FOLLOWLOCATION => true,
              CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
              CURLOPT_CUSTOMREQUEST => 'PATCH',
              CURLOPT_POSTFIELDS =>'{
                "properties": {
                      "number_of_videographer" :"'.$num_of_videographer.'"'.
                '}
              }',
              CURLOPT_HTTPHEADER => array(
                'Content-Type: application/json',
                'Authorization: Bearer ' . $privateAppToken,
              ),
            ));
        
            $deal_update_response = curl_exec($update_deal_curl);
            curl_close($update_deal_curl);
            return $deal_update_response;

}

function DealTotalPhotographer($privateAppToken, $dealId)
{
          $curl = curl_init();
          curl_setopt_array($curl, array(
          CURLOPT_URL => 'https://api.hubapi.com/crm/v3/objects/deals/'.$dealId.'?properties=number_of_photographer',
          CURLOPT_RETURNTRANSFER => true,
          CURLOPT_ENCODING => '',
          CURLOPT_MAXREDIRS => 10,
          CURLOPT_TIMEOUT => 0,
          CURLOPT_FOLLOWLOCATION => true,
          CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
          CURLOPT_CUSTOMREQUEST => 'GET',
          CURLOPT_HTTPHEADER => array(
            'Content-Type: application/json',
            'Authorization: ' . 'Bearer ' . $privateAppToken,
          ),
        ));
        
        $deal_response = curl_exec($curl);
        curl_close($curl);
        
        $responseData = json_decode( $deal_response , true);
        return $responseData;
    
}


function UpdateNumOfPhotographer($privateAppToken, $jobId, $num_of_photographer)
{
              
              $update_deal_curl = curl_init();
              curl_setopt_array($update_deal_curl, array(
              CURLOPT_URL => 'https://api.hubapi.com/crm/v3/objects/deals/' . $jobId,
              CURLOPT_RETURNTRANSFER => true,
              CURLOPT_ENCODING => '',
              CURLOPT_MAXREDIRS => 10,
              CURLOPT_TIMEOUT => 0,
              CURLOPT_FOLLOWLOCATION => true,
              CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
              CURLOPT_CUSTOMREQUEST => 'PATCH',
              CURLOPT_POSTFIELDS =>'{
                "properties": {
                      "number_of_photographer" :"'.$num_of_photographer.'"'.
                '}
              }',
              CURLOPT_HTTPHEADER => array(
                'Content-Type: application/json',
                'Authorization: Bearer ' . $privateAppToken,
              ),
            ));
        
            $deal_update_response = curl_exec($update_deal_curl);
            curl_close($update_deal_curl);
            return $deal_update_response;

}

function DealTotalDroneCoverage($privateAppToken, $dealId)
{
          $curl = curl_init();
          curl_setopt_array($curl, array(
          CURLOPT_URL => 'https://api.hubapi.com/crm/v3/objects/deals/'.$dealId.'?properties=number_of_drone_coverage',
          CURLOPT_RETURNTRANSFER => true,
          CURLOPT_ENCODING => '',
          CURLOPT_MAXREDIRS => 10,
          CURLOPT_TIMEOUT => 0,
          CURLOPT_FOLLOWLOCATION => true,
          CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
          CURLOPT_CUSTOMREQUEST => 'GET',
          CURLOPT_HTTPHEADER => array(
            'Content-Type: application/json',
            'Authorization: ' . 'Bearer ' . $privateAppToken,
          ),
        ));
        
        $deal_response = curl_exec($curl);
        curl_close($curl);
        
        $responseData = json_decode( $deal_response , true);
        return $responseData;
    
}

function UpdateNumOfDroneCoverage($privateAppToken, $jobId, $number_of_drone_coverage)
{
              
              $update_deal_curl = curl_init();
              curl_setopt_array($update_deal_curl, array(
              CURLOPT_URL => 'https://api.hubapi.com/crm/v3/objects/deals/' . $jobId,
              CURLOPT_RETURNTRANSFER => true,
              CURLOPT_ENCODING => '',
              CURLOPT_MAXREDIRS => 10,
              CURLOPT_TIMEOUT => 0,
              CURLOPT_FOLLOWLOCATION => true,
              CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
              CURLOPT_CUSTOMREQUEST => 'PATCH',
              CURLOPT_POSTFIELDS =>'{
                "properties": {
                      "number_of_drone_coverage" :"'.$number_of_drone_coverage.'"'.
                '}
              }',
              CURLOPT_HTTPHEADER => array(
                'Content-Type: application/json',
                'Authorization: Bearer ' . $privateAppToken,
              ),
            ));
        
            $deal_update_response = curl_exec($update_deal_curl);
            curl_close($update_deal_curl);
            return $deal_update_response;

}

function DealTotalVideoEditing($privateAppToken, $dealId)
{
          $curl = curl_init();
          curl_setopt_array($curl, array(
          CURLOPT_URL => 'https://api.hubapi.com/crm/v3/objects/deals/'.$dealId.'?properties=number_of_video_editor',
          CURLOPT_RETURNTRANSFER => true,
          CURLOPT_ENCODING => '',
          CURLOPT_MAXREDIRS => 10,
          CURLOPT_TIMEOUT => 0,
          CURLOPT_FOLLOWLOCATION => true,
          CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
          CURLOPT_CUSTOMREQUEST => 'GET',
          CURLOPT_HTTPHEADER => array(
            'Content-Type: application/json',
            'Authorization: ' . 'Bearer ' . $privateAppToken,
          ),
        ));
        
        $deal_response = curl_exec($curl);
        curl_close($curl);
        
        $responseData = json_decode( $deal_response , true);
        return $responseData;
    
}

function UpdateNumOfVideoEditor($privateAppToken, $jobId, $number_of_Video_Editor)
{
              
              $update_deal_curl = curl_init();
              curl_setopt_array($update_deal_curl, array(
              CURLOPT_URL => 'https://api.hubapi.com/crm/v3/objects/deals/' . $jobId,
              CURLOPT_RETURNTRANSFER => true,
              CURLOPT_ENCODING => '',
              CURLOPT_MAXREDIRS => 10,
              CURLOPT_TIMEOUT => 0,
              CURLOPT_FOLLOWLOCATION => true,
              CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
              CURLOPT_CUSTOMREQUEST => 'PATCH',
              CURLOPT_POSTFIELDS =>'{
                "properties": {
                      "number_of_video_editor" :"'.$number_of_Video_Editor.'"'.
                '}
              }',
              CURLOPT_HTTPHEADER => array(
                'Content-Type: application/json',
                'Authorization: Bearer ' . $privateAppToken,
              ),
            ));
        
            $deal_update_response = curl_exec($update_deal_curl);
            curl_close($update_deal_curl);
            return $deal_update_response;

}

function DealTotalVnW($privateAppToken, $dealId)
{
          $curl = curl_init();
          curl_setopt_array($curl, array(
          CURLOPT_URL => 'https://api.hubapi.com/crm/v3/objects/deals/'.$dealId.'?properties=number_of_video_streaming_and_webcasting_services',
          CURLOPT_RETURNTRANSFER => true,
          CURLOPT_ENCODING => '',
          CURLOPT_MAXREDIRS => 10,
          CURLOPT_TIMEOUT => 0,
          CURLOPT_FOLLOWLOCATION => true,
          CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
          CURLOPT_CUSTOMREQUEST => 'GET',
          CURLOPT_HTTPHEADER => array(
            'Content-Type: application/json',
            'Authorization: ' . 'Bearer ' . $privateAppToken,
          ),
        ));
        
        $deal_response = curl_exec($curl);
        curl_close($curl);
        
        $responseData = json_decode( $deal_response , true);
        return $responseData;
    
}

function UpdateNumOfVnW($privateAppToken, $jobId, $number_of_VnW)
{
              
              $update_deal_curl = curl_init();
              curl_setopt_array($update_deal_curl, array(
              CURLOPT_URL => 'https://api.hubapi.com/crm/v3/objects/deals/' . $jobId,
              CURLOPT_RETURNTRANSFER => true,
              CURLOPT_ENCODING => '',
              CURLOPT_MAXREDIRS => 10,
              CURLOPT_TIMEOUT => 0,
              CURLOPT_FOLLOWLOCATION => true,
              CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
              CURLOPT_CUSTOMREQUEST => 'PATCH',
              CURLOPT_POSTFIELDS =>'{
                "properties": {
                      "number_of_video_streaming_and_webcasting_services" :"'.$number_of_VnW.'"'.
                '}
              }',
              CURLOPT_HTTPHEADER => array(
                'Content-Type: application/json',
                'Authorization: Bearer ' . $privateAppToken,
              ),
            ));
        
            $deal_update_response = curl_exec($update_deal_curl);
            curl_close($update_deal_curl);
            return $deal_update_response;

}


function AssosiateCPtoJob($privateAppToken,$cpId,$jobID)
{

    $data = [
    "inputs" => [
        [
            "from" => [
                "id" => $jobID
            ],
            "to" => [
                "id" => $cpId
            ],
            "type" => "CP"
        ]
    ]
];
    $curl = curl_init();

    curl_setopt_array($curl, array(
      CURLOPT_URL => 'https://api.hubapi.com/crm/v3/associations/deals/contacts/batch/create',
      CURLOPT_RETURNTRANSFER => true,
      CURLOPT_ENCODING => '',
      CURLOPT_MAXREDIRS => 10,
      CURLOPT_TIMEOUT => 0,
      CURLOPT_FOLLOWLOCATION => true,
      CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
      CURLOPT_CUSTOMREQUEST => 'POST',
      CURLOPT_POSTFIELDS => json_encode($data),
      CURLOPT_HTTPHEADER => array(
        'Content-Type: application/json',
         'Authorization: Bearer ' . $privateAppToken,
      ),
    ));
    
    $response = curl_exec($curl);
    
    curl_close($curl);
    return $response;
    
}


// conatct contract send

function ContactJobClaimStatus($privateAppToken, $cp_id)
{
          $curl = curl_init();
          curl_setopt_array($curl, array(
          CURLOPT_URL => 'https://api.hubapi.com/crm/v3/objects/contact/'.$cp_id.'?properties=job_claim_status',
          CURLOPT_RETURNTRANSFER => true,
          CURLOPT_ENCODING => '',
          CURLOPT_MAXREDIRS => 10,
          CURLOPT_TIMEOUT => 0,
          CURLOPT_FOLLOWLOCATION => true,
          CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
          CURLOPT_CUSTOMREQUEST => 'GET',
          CURLOPT_HTTPHEADER => array(
            'Content-Type: application/json',
            'Authorization: ' . 'Bearer ' . $privateAppToken,
          ),
        ));
        
        $deal_response = curl_exec($curl);
        curl_close($curl);
        
        $responseData = json_decode( $deal_response , true);
        return $responseData;
    
}


// update contact notification

function UpdateContactNotification($privateAppToken, $cp_id, $notification) {
    $url = "https://api.hubapi.com/crm/v3/objects/contacts/$cp_id";
    
    $data = [
        "properties" => [
            "job_email_triggers" => $notification
        ]
    ];
    

    $ch = curl_init();
    
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "PATCH");
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        "Content-Type: application/json",
        "Authorization: Bearer $privateAppToken"
    ]);
    
    // Execute cURL request and get response
    $response = curl_exec($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    
    // Check for errors
    if (curl_errno($ch)) {
        echo "cURL Error: " . curl_error($ch);
    }
    
    // Close cURL
    curl_close($ch);
    
    // Return response and HTTP code
    return [
        "response" => $response,
        "httpCode" => $httpCode
    ];
}

function UpdateContractContact($privateAppToken, $cp_id, $contract_status) {
    $url = "https://api.hubapi.com/crm/v3/objects/contacts/$cp_id";
    
    $data = [
        "properties" => [
            "deal_contract" => $contract_status ? "true" : "false"
        ]
    ];
    

    $ch = curl_init();
    
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "PATCH");
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        "Content-Type: application/json",
        "Authorization: Bearer $privateAppToken"
    ]);
    
    // Execute cURL request and get response
    $response = curl_exec($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    
    // Check for errors
    if (curl_errno($ch)) {
        echo "cURL Error: " . curl_error($ch);
    }
    
    // Close cURL
    curl_close($ch);
    
    // Return response and HTTP code
    return [
        "response" => $response,
        "httpCode" => $httpCode
    ];
}

function DealServiceProvide($privateAppToken, $dealId)
{
          $curl = curl_init();
          curl_setopt_array($curl, array(
          CURLOPT_URL => 'https://api.hubapi.com/crm/v3/objects/deals/'.$dealId.'?properties=type_of_service',
          CURLOPT_RETURNTRANSFER => true,
          CURLOPT_ENCODING => '',
          CURLOPT_MAXREDIRS => 10,
          CURLOPT_TIMEOUT => 0,
          CURLOPT_FOLLOWLOCATION => true,
          CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
          CURLOPT_CUSTOMREQUEST => 'GET',
          CURLOPT_HTTPHEADER => array(
            'Content-Type: application/json',
            'Authorization: ' . 'Bearer ' . $privateAppToken,
          ),
        ));
        
        $deal_response = curl_exec($curl);
        curl_close($curl);
        
        $responseData = json_decode( $deal_response , true);
        return $responseData;
    
}



// deal notification Stage

function DealNotiStage($privateAppToken, $dealId)
{
          $curl = curl_init();
          curl_setopt_array($curl, array(
          CURLOPT_URL => 'https://api.hubapi.com/crm/v3/objects/deals/'.$dealId.'?properties=job_notification_stage',
          CURLOPT_RETURNTRANSFER => true,
          CURLOPT_ENCODING => '',
          CURLOPT_MAXREDIRS => 10,
          CURLOPT_TIMEOUT => 0,
          CURLOPT_FOLLOWLOCATION => true,
          CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
          CURLOPT_CUSTOMREQUEST => 'GET',
          CURLOPT_HTTPHEADER => array(
            'Content-Type: application/json',
            'Authorization: ' . 'Bearer ' . $privateAppToken,
          ),
        ));
        
        $deal_response = curl_exec($curl);
        curl_close($curl);
        
        $responseData = json_decode( $deal_response , true);
        return $responseData;
}

// Discord functions



function getDealAssociatedContacts($privateAppToken, $dealId) {
    $url = "https://api.hubapi.com/crm/v3/associations/deals/contacts/batch/read";

    $payload = [
        "inputs" => [
            ["id" => $dealId]
        ]
    ];

    $ch = curl_init($url);

    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        "Authorization: Bearer {$privateAppToken}",
        "Content-Type: application/json"
    ]);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($payload));

    $response = curl_exec($ch);

    if (curl_errno($ch)) {
        $error_msg = curl_error($ch);
        curl_close($ch);
        return "cURL error: {$error_msg}";
    }

    $http_status = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);

    if ($http_status === 200) {
        return json_decode($response, true);
    } else {
        return "Error: HTTP Status {$http_status}, Response: {$response}";
    }
}

function getContactPhoneNumber($hubspotToken, $contactId) {
    $url = "https://api.hubapi.com/crm/v3/objects/contacts/{$contactId}?properties=phone";

    $ch = curl_init($url);

    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        "Authorization: Bearer {$hubspotToken}",
        "Content-Type: application/json"
    ]);
    curl_setopt($ch, CURLOPT_HTTPGET, true);

    $response = curl_exec($ch);

    if (curl_errno($ch)) {
        $error_msg = curl_error($ch);
        curl_close($ch);
        return "cURL error: {$error_msg}";
    }

    $http_status = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);

    if ($http_status === 200) {
        $result = json_decode($response, true);

        $phone = $result['properties']['phone'] ?? null;
        return $phone;
    } else {
        return "Error: HTTP Status {$http_status}, Response: {$response}";
    }
}

// job pipeline stage sms notify

function dealAssociateContact($accessToken, $dealId) {
    $names = [];
    $mobileNumbers = [];

    $baseUrl = "https://api.hubapi.com";
    

    $endpoint = "/crm/v4/objects/deals/$dealId/associations/contacts";
    
    $ch = curl_init();
    
    curl_setopt($ch, CURLOPT_URL, $baseUrl . $endpoint);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        "Authorization: Bearer $accessToken",
        "Content-Type: application/json"
    ]);
    
    // Execute the request
    $response = curl_exec($ch);
    
    // Check for errors
    if (curl_errno($ch)) {
        echo "cURL Error: " . curl_error($ch);
        curl_close($ch);
        return;
    }
    
    // Parse the response
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);
    
    if ($httpCode === 200) {
        // Decode JSON response
        $data = json_decode($response, true);
        $results = $data['results'] ?? [];
        
        foreach ($results as $result) {
            $contactId = $result['toObjectId'] ?? null;
            
            // Fetch contact details if the contact ID exists
            if ($contactId) {
                $contactDetails = fetchContactDetails($accessToken, $contactId);
                if ($contactDetails) {
                    // Add full name and mobile number to respective arrays
                    $names[] = $contactDetails['fullName'];
                    $mobileNumbers[] = $contactDetails['mobile'];
                }
            }
        }
    } else {
        echo "Error: Unable to fetch associated contacts. HTTP Code: $httpCode\n";
        echo "Response: $response\n";
    }
    
    echo "Names:\n";
    print_r($names);
    
    echo "Mobile Numbers:\n";
    print_r($mobileNumbers);
}

function fetchContactDetails($accessToken, $contactId) {

    $baseUrl = "https://api.hubapi.com";
    
    $endpoint = "/crm/v3/objects/contacts/$contactId?properties=firstname,lastname,phone";
    
    $ch = curl_init();
    
    curl_setopt($ch, CURLOPT_URL, $baseUrl . $endpoint);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        "Authorization: Bearer $accessToken",
        "Content-Type: application/json"
    ]);
    
    $response = curl_exec($ch);
    
    if (curl_errno($ch)) {
        echo "cURL Error: " . curl_error($ch);
        curl_close($ch);
        return false;
    }
    

    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);
    
    if ($httpCode === 200) {
        $data = json_decode($response, true);
        return [
            'id' => $data['id'] ?? null,
            'fullName' => ($data['properties']['firstname'] ?? '') . ' ' . ($data['properties']['lastname'] ?? ''),
            'mobile' => $data['properties']['phone'] ?? null,
        ];
    } else {
        echo "Error: Unable to fetch contact details. HTTP Code: $httpCode\n";
        echo "Response: $response\n";
        return false;
    }
}

?>